pilot.api.compute.api

Package pilot :: Package api :: Package compute :: Module api |

# Module api

source code

Pilot Compute related entities.

Classes
| State State.
| PilotComputeDescription PilotComputeDescription (PCD).
| PilotCompute PilotCompute (PC).
| PilotComputeService PilotComputeService (PCS).
| ComputeUnitService ComputeUnitService (CUS).
| ComputeUnitDescription ComputeUnitDescription (CUD).
| ComputeUnit ComputeUnit (CU).
| Callback Callback class.

Variables
| __package__ = `None` hash(x)